CVS commit: src/sys/sys

2021-06-03 Thread Jason R Thorpe
Module Name:src
Committed By:   thorpej
Date:   Fri Jun  4 01:58:02 UTC 2021

Modified Files:
src/sys/sys: cdefs_elf.h

Log Message:
Fix some badly-aligned line continuation escapes.


To generate a diff of this commit:
cvs rdiff -u -r1.57 -r1.58 src/sys/sys/cdefs_elf.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/sys/cdefs_elf.h
diff -u src/sys/sys/cdefs_elf.h:1.57 src/sys/sys/cdefs_elf.h:1.58
--- src/sys/sys/cdefs_elf.h:1.57	Thu Apr 30 14:32:05 2020
+++ src/sys/sys/cdefs_elf.h	Fri Jun  4 01:58:02 2021
@@ -1,4 +1,4 @@
-/*	$NetBSD: cdefs_elf.h,v 1.57 2020/04/30 14:32:05 joerg Exp $	*/
+/*	$NetBSD: cdefs_elf.h,v 1.58 2021/06/04 01:58:02 thorpej Exp $	*/
 
 /*
  * Copyright (c) 1995, 1996 Carnegie-Mellon University.
@@ -31,10 +31,10 @@
 #define	_SYS_CDEFS_ELF_H_
 
 #ifdef __LEADING_UNDERSCORE
-#define	_C_LABEL(x)	__CONCAT(_,x)
+#define	_C_LABEL(x)		__CONCAT(_,x)
 #define _C_LABEL_STRING(x)	"_"x
 #else
-#define	_C_LABEL(x)	x
+#define	_C_LABEL(x)		x
 #define _C_LABEL_STRING(x)	x
 #endif
 
@@ -57,7 +57,7 @@
 	_C_LABEL_STRING(#alias) " = " _C_LABEL_STRING(#sym));
 
 #define	__weak_alias(alias,sym)		\
-__asm(".weak " _C_LABEL_STRING(#alias) "\n"			\
+__asm(".weak " _C_LABEL_STRING(#alias) "\n"\
 	_C_LABEL_STRING(#alias) " = " _C_LABEL_STRING(#sym));
 
 /* Do not use __weak_extern, use __weak_reference instead */
@@ -136,12 +136,12 @@
 
 #ifdef __arm__
 #if __STDC__
-#  define	__SECTIONSTRING(_sec, _str)	\
+#  define	__SECTIONSTRING(_sec, _str)\
 	__asm(".pushsection " #_sec ",\"MS\",%progbits,1\n"		\
 	  ".asciz \"" _str "\"\n"	\
 	  ".popsection")
 #else
-#  define	__SECTIONSTRING(_sec, _str)	\
+#  define	__SECTIONSTRING(_sec, _str)\
 	__asm(".pushsection " _sec ",\"MS\",%progbits,1\n"		\
 	  ".asciz \"" _str "\"\n"	\
 	  ".popsection")



CVS commit: src/external/gpl3/gdb/dist/gdb

2021-06-03 Thread Rin Okuyama
Module Name:src
Committed By:   rin
Date:   Fri Jun  4 01:42:14 UTC 2021

Modified Files:
src/external/gpl3/gdb/dist/gdb: aarch64-nbsd-tdep.c

Log Message:
Add missing nbsd_init_abi() call to aarch64_nbsd_init_abi().

Fix tests/usr.bin/gdb/t_regress:pie on aarch64eb (types of auxv was
misinterpreted), and hopefully other strange behaviors on aarch64{,eb}.

This is a regression introduced in GDB11. Neither gdb.old nor release
branches are affected.


To generate a diff of this commit:
cvs rdiff -u -r1.7 -r1.8 src/external/gpl3/gdb/dist/gdb/aarch64-nbsd-tdep.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/gpl3/gdb/dist/gdb/aarch64-nbsd-tdep.c
diff -u src/external/gpl3/gdb/dist/gdb/aarch64-nbsd-tdep.c:1.7 src/external/gpl3/gdb/dist/gdb/aarch64-nbsd-tdep.c:1.8
--- src/external/gpl3/gdb/dist/gdb/aarch64-nbsd-tdep.c:1.7	Fri Dec 11 18:23:25 2020
+++ src/external/gpl3/gdb/dist/gdb/aarch64-nbsd-tdep.c	Fri Jun  4 01:42:14 2021
@@ -182,6 +182,8 @@ aarch64_nbsd_init_abi (struct gdbarch_in
 {
   struct gdbarch_tdep *tdep = gdbarch_tdep (gdbarch);
 
+  nbsd_init_abi (info, gdbarch);
+
   set_solib_svr4_fetch_link_map_offsets (gdbarch,
 	 svr4_lp64_fetch_link_map_offsets);
 



CVS commit: src

2021-06-03 Thread Taylor R Campbell
Module Name:src
Committed By:   riastradh
Date:   Thu Jun  3 20:18:06 UTC 2021

Modified Files:
src/share/man/man4: options.4
src/sys/uvm: files.uvm uvm_swap.c

Log Message:
uvm(9): Enable swap encryption by default.

For machines where the performance impact of swapping before the
system has an opportunity to process `vm.swap_encrypt=0' in
/etc/sysctl.conf, you can disable it again by adding

options VMSWAP_DEFAULT_PLAINTEXT

to the kernel config.


To generate a diff of this commit:
cvs rdiff -u -r1.518 -r1.519 src/share/man/man4/options.4
cvs rdiff -u -r1.36 -r1.37 src/sys/uvm/files.uvm
cvs rdiff -u -r1.204 -r1.205 src/sys/uvm/uvm_swap.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/share/man/man4/options.4
diff -u src/share/man/man4/options.4:1.518 src/share/man/man4/options.4:1.519
--- src/share/man/man4/options.4:1.518	Sun Mar 14 02:56:07 2021
+++ src/share/man/man4/options.4	Thu Jun  3 20:18:06 2021
@@ -1,4 +1,4 @@
-.\"	$NetBSD: options.4,v 1.518 2021/03/14 02:56:07 rin Exp $
+.\"	$NetBSD: options.4,v 1.519 2021/06/03 20:18:06 riastradh Exp $
 .\"
 .\" Copyright (c) 1996
 .\" 	Perry E. Metzger.  All rights reserved.
@@ -2203,6 +2203,16 @@ for details.
 .It Cd options VMSWAP
 Enable paging device/file support.
 This option is on by default.
+.It Cd options VMSWAP_DEFAULT_PLAINTEXT
+Store swap in plaintext, not encrypted, which may expose secrets if the
+underlying nonvolatile medium is disclosed.
+This option is off by default; it is available only for extremely slow
+machines where the performance impact of swapping early at boot
+outweighs the security risks.
+Swap encryption can still be turned on dynamically with the
+.Em vm.swap_encrypt
+.Xr sysctl 7
+knob.
 .It Cd options PDPOLICY_CLOCKPRO
 Use CLOCK-Pro, an alternative page replace policy.
 .El

Index: src/sys/uvm/files.uvm
diff -u src/sys/uvm/files.uvm:1.36 src/sys/uvm/files.uvm:1.37
--- src/sys/uvm/files.uvm:1.36	Tue Aug  4 06:10:27 2020
+++ src/sys/uvm/files.uvm	Thu Jun  3 20:18:06 2021
@@ -1,4 +1,4 @@
-#	$NetBSD: files.uvm,v 1.36 2020/08/04 06:10:27 skrll Exp $
+#	$NetBSD: files.uvm,v 1.37 2021/06/03 20:18:06 riastradh Exp $
 
 #
 # UVM options
@@ -8,6 +8,7 @@ defflag opt_uvmhist.h		UVMHIST_PRINT: KE
 defparam opt_uvmhist.h		UVMHIST_MAPHIST_SIZE UVMHIST_PDHIST_SIZE
 defflag opt_uvm.h		UVMMAP_COUNTERS
 defparam opt_uvm.h		UVM_RESERVED_PAGES_PER_CPU
+defflag opt_vmswap.h		VMSWAP_DEFAULT_PLAINTEXT
 defflag opt_vmswap.h		VMSWAP : aes
 defflag opt_readahead.h		READAHEAD_STATS
 defflag opt_ubc.h		UBC_STATS

Index: src/sys/uvm/uvm_swap.c
diff -u src/sys/uvm/uvm_swap.c:1.204 src/sys/uvm/uvm_swap.c:1.205
--- src/sys/uvm/uvm_swap.c:1.204	Sun May 23 00:36:36 2021
+++ src/sys/uvm/uvm_swap.c	Thu Jun  3 20:18:06 2021
@@ -1,4 +1,4 @@
-/*	$NetBSD: uvm_swap.c,v 1.204 2021/05/23 00:36:36 mrg Exp $	*/
+/*	$NetBSD: uvm_swap.c,v 1.205 2021/06/03 20:18:06 riastradh Exp $	*/
 
 /*
  * Copyright (c) 1995, 1996, 1997, 2009 Matthew R. Green
@@ -30,11 +30,12 @@
  */
 
 #include 
-__KERNEL_RCSID(0, "$NetBSD: uvm_swap.c,v 1.204 2021/05/23 00:36:36 mrg Exp $");
+__KERNEL_RCSID(0, "$NetBSD: uvm_swap.c,v 1.205 2021/06/03 20:18:06 riastradh Exp $");
 
 #include "opt_uvmhist.h"
 #include "opt_compat_netbsd.h"
 #include "opt_ddb.h"
+#include "opt_vmswap.h"
 
 #include 
 #include 
@@ -210,7 +211,11 @@ static struct workqueue *sw_reg_workqueu
 
 /* tuneables */
 u_int uvm_swapisfull_factor = 99;
+#if VMSWAP_DEFAULT_PLAINTEXT
 bool uvm_swap_encrypt = false;
+#else
+bool uvm_swap_encrypt = true;
+#endif
 
 /*
  * prototypes



CVS commit: src/tests/lib/csu

2021-06-03 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Thu Jun  3 20:17:37 UTC 2021

Modified Files:
src/tests/lib/csu: h_ifunc_static.c

Log Message:
PR/56230: Jan-Benedict Glaw: arm oabi does not and will not have ifunc support.


To generate a diff of this commit:
cvs rdiff -u -r1.2 -r1.3 src/tests/lib/csu/h_ifunc_static.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/tests/lib/csu/h_ifunc_static.c
diff -u src/tests/lib/csu/h_ifunc_static.c:1.2 src/tests/lib/csu/h_ifunc_static.c:1.3
--- src/tests/lib/csu/h_ifunc_static.c:1.2	Sun Mar 11 17:20:22 2018
+++ src/tests/lib/csu/h_ifunc_static.c	Thu Jun  3 16:17:37 2021
@@ -1,4 +1,4 @@
-/*	$NetBSD: h_ifunc_static.c,v 1.2 2018/03/11 21:20:22 joerg Exp $	*/
+/*	$NetBSD: h_ifunc_static.c,v 1.3 2021/06/03 20:17:37 christos Exp $	*/
 
 /*-
  * Copyright (c) 2018 The NetBSD Foundation, Inc.
@@ -29,7 +29,7 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
-#if defined(__arm__) || defined(__i386__) || defined(__x86_64__) || defined(__powerpc__) || defined(__sparc__)
+#if (defined(__arm__) && defined(__ARM_EABI__)) || defined(__i386__) || defined(__x86_64__) || defined(__powerpc__) || defined(__sparc__)
 #include 
 #include 
 



CVS commit: src/sys/modules

2021-06-03 Thread Nia Alarie
Module Name:src
Committed By:   nia
Date:   Thu Jun  3 15:59:04 UTC 2021

Modified Files:
src/sys/modules/drmkms: Makefile
src/sys/modules/i915drmkms: Makefile
src/sys/modules/radeondrm: Makefile

Log Message:
build the drmkms modules with -fwrapv too


To generate a diff of this commit:
cvs rdiff -u -r1.13 -r1.14 src/sys/modules/drmkms/Makefile
cvs rdiff -u -r1.17 -r1.18 src/sys/modules/i915drmkms/Makefile
cvs rdiff -u -r1.14 -r1.15 src/sys/modules/radeondrm/Makefile

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/modules/drmkms/Makefile
diff -u src/sys/modules/drmkms/Makefile:1.13 src/sys/modules/drmkms/Makefile:1.14
--- src/sys/modules/drmkms/Makefile:1.13	Fri Feb 14 09:35:52 2020
+++ src/sys/modules/drmkms/Makefile	Thu Jun  3 15:59:04 2021
@@ -1,4 +1,4 @@
-# $NetBSD: Makefile,v 1.13 2020/02/14 09:35:52 riastradh Exp $
+# $NetBSD: Makefile,v 1.14 2021/06/03 15:59:04 nia Exp $
 
 .include "../Makefile.inc"
 .include "Makefile.inc"
@@ -25,6 +25,9 @@ SRCS+=	drmfb.c
 
 # XXX ttm
 
+# Code imported from Linux - expects signed overflow to be OK.
+COPTS+=	-fwrapv
+
 CPPFLAGS+=	-I.
 
 # XXX CWARNFLAGS.foo.c doesn't work.

Index: src/sys/modules/i915drmkms/Makefile
diff -u src/sys/modules/i915drmkms/Makefile:1.17 src/sys/modules/i915drmkms/Makefile:1.18
--- src/sys/modules/i915drmkms/Makefile:1.17	Tue Apr 13 04:59:00 2021
+++ src/sys/modules/i915drmkms/Makefile	Thu Jun  3 15:59:04 2021
@@ -1,4 +1,4 @@
-# $NetBSD: Makefile,v 1.17 2021/04/13 04:59:00 mrg Exp $
+# $NetBSD: Makefile,v 1.18 2021/06/03 15:59:04 nia Exp $
 
 .include "../Makefile.inc"
 .include "../drmkms/Makefile.inc"
@@ -27,6 +27,9 @@ CPPFLAGS+=	-DNVGA=1
 CWARNFLAGS+=	-Wno-shadow
 CWARNFLAGS+=	-Wno-pointer-arith
 
+# Code imported from Linux - expects signed overflow to be OK.
+COPTS+=		-fwrapv
+
 COPTS.i915_drv.c+=	${${ACTIVE_CC} == "gcc":? -Wno-override-init :}
 COPTS.i915_drv.c+=	${${ACTIVE_CC} == "clang":? -Wno-initializer-overrides :}
 

Index: src/sys/modules/radeondrm/Makefile
diff -u src/sys/modules/radeondrm/Makefile:1.14 src/sys/modules/radeondrm/Makefile:1.15
--- src/sys/modules/radeondrm/Makefile:1.14	Mon Nov 11 22:45:27 2019
+++ src/sys/modules/radeondrm/Makefile	Thu Jun  3 15:59:04 2021
@@ -1,4 +1,4 @@
-# $NetBSD: Makefile,v 1.14 2019/11/11 22:45:27 joerg Exp $
+# $NetBSD: Makefile,v 1.15 2021/06/03 15:59:04 nia Exp $
 
 .include "../Makefile.inc"
 
@@ -18,6 +18,9 @@ SRCS+=	radeon_irq.c
 SRCS+=	radeon_mem.c
 SRCS+=	radeon_state.c
 
+# Code imported from Linux - expects signed overflow to be OK.
+COPTS+=	-fwrapv
+
 CPPFLAGS+=	-I${S}/external/bsd/drm/dist/bsd-core \
 		-I${S}/external/bsd/drm/dist/shared-core
 



CVS commit: src/sbin/cgdconfig

2021-06-03 Thread Patrick Welche
Module Name:src
Committed By:   prlw1
Date:   Thu Jun  3 15:40:27 UTC 2021

Modified Files:
src/sbin/cgdconfig: params.c

Log Message:
Make adiantum a first class citizen


To generate a diff of this commit:
cvs rdiff -u -r1.30 -r1.31 src/sbin/cgdconfig/params.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sbin/cgdconfig/params.c
diff -u src/sbin/cgdconfig/params.c:1.30 src/sbin/cgdconfig/params.c:1.31
--- src/sbin/cgdconfig/params.c:1.30	Sun Dec 30 12:05:48 2018
+++ src/sbin/cgdconfig/params.c	Thu Jun  3 15:40:27 2021
@@ -1,4 +1,4 @@
-/* $NetBSD: params.c,v 1.30 2018/12/30 12:05:48 mlelstv Exp $ */
+/* $NetBSD: params.c,v 1.31 2021/06/03 15:40:27 prlw1 Exp $ */
 
 /*-
  * Copyright (c) 2002, 2003 The NetBSD Foundation, Inc.
@@ -31,7 +31,7 @@
 
 #include 
 #ifndef lint
-__RCSID("$NetBSD: params.c,v 1.30 2018/12/30 12:05:48 mlelstv Exp $");
+__RCSID("$NetBSD: params.c,v 1.31 2021/06/03 15:40:27 prlw1 Exp $");
 #endif
 
 #include 
@@ -69,6 +69,7 @@ static struct crypto_defaults {
 	char	alg[32];
 	int	keylen;
 } crypto_defaults[] = {
+	{ "adiantum",		256 },
 	{ "aes-cbc",		128 },
 	{ "aes-xts",		256 },
 	{ "3des-cbc",		192 },



CVS commit: src/distrib/sets/lists/man

2021-06-03 Thread Thomas Klausner
Module Name:src
Committed By:   wiz
Date:   Thu Jun  3 13:16:42 UTC 2021

Modified Files:
src/distrib/sets/lists/man: mi

Log Message:
Fix typo, caught by riastradh


To generate a diff of this commit:
cvs rdiff -u -r1.1721 -r1.1722 src/distrib/sets/lists/man/mi

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/distrib/sets/lists/man/mi
diff -u src/distrib/sets/lists/man/mi:1.1721 src/distrib/sets/lists/man/mi:1.1722
--- src/distrib/sets/lists/man/mi:1.1721	Thu Jun  3 07:41:26 2021
+++ src/distrib/sets/lists/man/mi	Thu Jun  3 13:16:41 2021
@@ -1,4 +1,4 @@
-# $NetBSD: mi,v 1.1721 2021/06/03 07:41:26 wiz Exp $
+# $NetBSD: mi,v 1.1722 2021/06/03 13:16:41 wiz Exp $
 #
 # Note: don't delete entries from here - mark them as "obsolete" instead.
 #
@@ -4489,7 +4489,7 @@
 ./usr/share/man/html4/hythygtemp.html		man-sys-htmlman		html
 ./usr/share/man/html4/i386/PCIBIOS.html		man-sys-htmlman		html
 ./usr/share/man/html4/i386/apm.html		man-sys-htmlman		html
-./usr/share/man/html4/386/autoconf.html	man-obsolete		obsolete
+./usr/share/man/html4/i386/autoconf.html	man-obsolete		obsolete
 ./usr/share/man/html4/i386/cmos.html		man-sys-htmlman		html
 ./usr/share/man/html4/i386/cons.html		man-obsolete		obsolete
 ./usr/share/man/html4/i386/console.html		man-obsolete		obsolete



CVS commit: src/usr.bin/ftp

2021-06-03 Thread Luke Mewburn
Module Name:src
Committed By:   lukem
Date:   Thu Jun  3 10:23:33 UTC 2021

Modified Files:
src/usr.bin/ftp: Makefile ssl.c ssl.h version.h

Log Message:
use fetch_*() for I/O with SMALLPROG / !WITH_SSL builds

Adapt the SMALLPROG / -UWITH_SSL build to also use the fetch_*()
methods from ssl.c, instead of using stdio, as stdio isn't robust
when using interruptable signals.

Disable ssl-specific support in the fetch_*() methods if WITH_SSL
isn't defined, so SMALLPROG still doesn't have ssl support (as expected).

The resulting SMALLPROG binary is slightly larger than before
(e.g., 157KiB vs 153KiB on amd64).

Set version to 20210603 for this fix and the SO_KEEPALIVE fix for PR 56129.

PR install/56219


To generate a diff of this commit:
cvs rdiff -u -r1.38 -r1.39 src/usr.bin/ftp/Makefile
cvs rdiff -u -r1.9 -r1.10 src/usr.bin/ftp/ssl.c
cvs rdiff -u -r1.4 -r1.5 src/usr.bin/ftp/ssl.h
cvs rdiff -u -r1.92 -r1.93 src/usr.bin/ftp/version.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/usr.bin/ftp/Makefile
diff -u src/usr.bin/ftp/Makefile:1.38 src/usr.bin/ftp/Makefile:1.39
--- src/usr.bin/ftp/Makefile:1.38	Sun Sep  6 07:20:31 2020
+++ src/usr.bin/ftp/Makefile	Thu Jun  3 10:23:33 2021
@@ -1,4 +1,4 @@
-#	$NetBSD: Makefile,v 1.38 2020/09/06 07:20:31 mrg Exp $
+#	$NetBSD: Makefile,v 1.39 2021/06/03 10:23:33 lukem Exp $
 #	from: @(#)Makefile	8.2 (Berkeley) 4/3/94
 
 .include 
@@ -8,6 +8,7 @@ USE_FORT?= yes	# network client
 PROG=	ftp
 SRCS=	cmds.c cmdtab.c complete.c domacro.c fetch.c ftp.c main.c \
 	progressbar.c ruserpass.c util.c
+SRCS+=	ssl.c
 
 # Uncomment the following to provide defaults for gate-ftp operation
 #
@@ -19,7 +20,6 @@ CPPFLAGS+=-DNO_EDITCOMPLETE -DNO_ABOUT -
 LDADD+=	-ledit -lterminfo
 DPADD+=	${LIBEDIT} ${LIBTERMINFO}
 CPPFLAGS+= -DWITH_SSL
-SRCS+=ssl.c
 LDADD+= -lssl -lcrypto
 DPADD+= ${LIBSSL} ${LIBCRYPTO}
 .endif

Index: src/usr.bin/ftp/ssl.c
diff -u src/usr.bin/ftp/ssl.c:1.9 src/usr.bin/ftp/ssl.c:1.10
--- src/usr.bin/ftp/ssl.c:1.9	Wed Jan  6 04:43:14 2021
+++ src/usr.bin/ftp/ssl.c	Thu Jun  3 10:23:33 2021
@@ -1,4 +1,4 @@
-/*	$NetBSD: ssl.c,v 1.9 2021/01/06 04:43:14 lukem Exp $	*/
+/*	$NetBSD: ssl.c,v 1.10 2021/06/03 10:23:33 lukem Exp $	*/
 
 /*-
  * Copyright (c) 1998-2004 Dag-Erling Coïdan Smørgrav
@@ -34,13 +34,17 @@
 
 #include 
 #ifndef lint
-__RCSID("$NetBSD: ssl.c,v 1.9 2021/01/06 04:43:14 lukem Exp $");
+__RCSID("$NetBSD: ssl.c,v 1.10 2021/06/03 10:23:33 lukem Exp $");
 #endif
 
+#include 
+#include 
+#include 
+#include 
+#include 
+#include 
 #include 
 #include 
-#include 
-#include 
 
 #include 
 #include 
@@ -48,11 +52,14 @@ __RCSID("$NetBSD: ssl.c,v 1.9 2021/01/06
 
 #include 
 #include 
+
+#ifdef WITH_SSL
 #include 
 #include 
 #include 
 #include 
 #include 
+#endif
 
 #include "ssl.h"
 
@@ -75,7 +82,9 @@ struct fetch_connect {
 	int 			 issock;
 	int			 iserr;
 	int			 iseof;
+#ifdef WITH_SSL
 	SSL			*ssl;		/* SSL handle */
+#endif
 };
 
 /*
@@ -121,9 +130,11 @@ fetch_writev(struct fetch_connect *conn,
 			}
 		}
 		errno = 0;
+#ifdef WITH_SSL
 		if (conn->ssl != NULL)
 			len = SSL_write(conn->ssl, iov->iov_base, iov->iov_len);
 		else
+#endif
 			len = writev(fd, iov, iovcnt);
 		if (len == 0) {
 			/* we consider a short write a failure */
@@ -275,7 +286,9 @@ fetch_close(struct fetch_connect *conn)
 		return 0;
 
 	fetch_flush(conn);
+#ifdef WITH_SSL
 	SSL_free(conn->ssl);
+#endif
 	close(conn->sd);
 	free(conn->cache.buf);
 	free(conn->buf);
@@ -287,6 +300,7 @@ fetch_close(struct fetch_connect *conn)
 #define FETCH_READ_WAIT		-2
 #define FETCH_READ_ERROR	-1
 
+#ifdef WITH_SSL
 static ssize_t
 fetch_ssl_read(SSL *ssl, void *buf, size_t len)
 {
@@ -305,6 +319,7 @@ fetch_ssl_read(SSL *ssl, void *buf, size
 		return FETCH_READ_ERROR;
 	}
 }
+#endif /* WITH_SSL */
 
 static ssize_t
 fetch_nonssl_read(int sd, void *buf, size_t len)
@@ -433,9 +448,11 @@ fetch_read(void *ptr, size_t size, size_
 		 * In the non-SSL case, it may improve performance (very
 		 * slightly) when reading small amounts of data.
 		 */
+#ifdef WITH_SSL
 		if (conn->ssl != NULL)
 			rlen = fetch_ssl_read(conn->ssl, buf, len);
 		else
+#endif
 			rlen = fetch_nonssl_read(conn->sd, buf, len);
 		switch (rlen) {
 		case 0:
@@ -564,6 +581,7 @@ fetch_getline(struct fetch_connect *conn
 	return len;
 }
 
+#ifdef WITH_SSL
 void *
 fetch_start_ssl(int sock, const char *servername)
 {
@@ -624,10 +642,13 @@ fetch_start_ssl(int sock, const char *se
 
 	return ssl;
 }
+#endif /* WITH_SSL */
 
 
 void
 fetch_set_ssl(struct fetch_connect *conn, void *ssl)
 {
+#ifdef WITH_SSL
 	conn->ssl = ssl;
+#endif
 }

Index: src/usr.bin/ftp/ssl.h
diff -u src/usr.bin/ftp/ssl.h:1.4 src/usr.bin/ftp/ssl.h:1.5
--- src/usr.bin/ftp/ssl.h:1.4	Thu Apr  4 00:36:09 2019
+++ src/usr.bin/ftp/ssl.h	Thu Jun  3 10:23:33 2021
@@ -1,7 +1,7 @@
-/*	$NetBSD: ssl.h,v 1.4

CVS commit: [cjep_sun2x] src/share/mk

2021-06-03 Thread Chris Pinnock
Module Name:src
Committed By:   cjep
Date:   Thu Jun  3 10:18:30 UTC 2021

Modified Files:
src/share/mk [cjep_sun2x]: bsd.x11.mk

Log Message:
avoid Xt duplication


To generate a diff of this commit:
cvs rdiff -u -r1.138.4.1 -r1.138.4.2 src/share/mk/bsd.x11.mk

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/share/mk/bsd.x11.mk
diff -u src/share/mk/bsd.x11.mk:1.138.4.1 src/share/mk/bsd.x11.mk:1.138.4.2
--- src/share/mk/bsd.x11.mk:1.138.4.1	Wed Jun  2 14:22:55 2021
+++ src/share/mk/bsd.x11.mk	Thu Jun  3 10:18:30 2021
@@ -1,4 +1,4 @@
-#	$NetBSD: bsd.x11.mk,v 1.138.4.1 2021/06/02 14:22:55 cjep Exp $
+#	$NetBSD: bsd.x11.mk,v 1.138.4.2 2021/06/03 10:18:30 cjep Exp $
 
 .include 
 
@@ -254,7 +254,7 @@ XLIBDPADD_XMUU=		${LIBXMUU} ${XLIBDPADD_
 
 # XAW depends on XMU and XPM which have overlapping dependencies
 #
-XLIBLDADD_XMU_XPM=	-lXmu -lXt -lXpm ${XLIBLDADD_XT_XEXT}
+XLIBLDADD_XMU_XPM=	-lXmu -lXpm ${XLIBLDADD_XT_XEXT}
 XLIBDPADD_XMU_XPM=	${LIBXMU} ${LIBXT} ${LIBXPM} ${XLIBDPADD_XT_XEXT}
 
 XLIBLDADD_XAW=		-lXaw ${XLIBLDADD_XMU_XPM}



CVS commit: src/usr.bin/ftp

2021-06-03 Thread Luke Mewburn
Module Name:src
Committed By:   lukem
Date:   Thu Jun  3 10:11:00 UTC 2021

Modified Files:
src/usr.bin/ftp: ftp.c

Log Message:
set SO_KEEPALIVE on control connection

Attempt to prevent timeouts of the control connection by setting SO_KEEPALIVE.
This matches the equivalent behaviour in ftpd.

Note: This is a much simpler change than adding a background polling event
to invoke "STAT" (or "NOOP") on the control connection during a transfer.
(It's unclear from RFC 959 whether "NOOP" is even permitted during a transfer).

PR bin/56129


To generate a diff of this commit:
cvs rdiff -u -r1.171 -r1.172 src/usr.bin/ftp/ftp.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/usr.bin/ftp/ftp.c
diff -u src/usr.bin/ftp/ftp.c:1.171 src/usr.bin/ftp/ftp.c:1.172
--- src/usr.bin/ftp/ftp.c:1.171	Wed Jan  6 04:43:14 2021
+++ src/usr.bin/ftp/ftp.c	Thu Jun  3 10:11:00 2021
@@ -1,4 +1,4 @@
-/*	$NetBSD: ftp.c,v 1.171 2021/01/06 04:43:14 lukem Exp $	*/
+/*	$NetBSD: ftp.c,v 1.172 2021/06/03 10:11:00 lukem Exp $	*/
 
 /*-
  * Copyright (c) 1996-2021 The NetBSD Foundation, Inc.
@@ -92,7 +92,7 @@
 #if 0
 static char sccsid[] = "@(#)ftp.c	8.6 (Berkeley) 10/27/94";
 #else
-__RCSID("$NetBSD: ftp.c,v 1.171 2021/01/06 04:43:14 lukem Exp $");
+__RCSID("$NetBSD: ftp.c,v 1.172 2021/06/03 10:11:00 lukem Exp $");
 #endif
 #endif /* not lint */
 
@@ -280,6 +280,11 @@ hookup(const char *host, const char *por
 		goto bad;
 	}
 
+	if (setsockopt(s, SOL_SOCKET, SO_KEEPALIVE,
+			(void *), sizeof(on)) == -1) {
+		DWARN("setsockopt %s (ignored)", "SO_KEEPALIVE");
+	}
+
 	if (setsockopt(s, SOL_SOCKET, SO_OOBINLINE,
 			(void *), sizeof(on)) == -1) {
 		DWARN("setsockopt %s (ignored)", "SO_OOBINLINE");



CVS commit: src/sys/kern

2021-06-03 Thread Taylor R Campbell
Module Name:src
Committed By:   riastradh
Date:   Thu Jun  3 09:22:47 UTC 2021

Modified Files:
src/sys/kern: kern_ksyms.c

Log Message:
ksyms(4): Allow multiple concurrent opens of /dev/ksyms.

First one takes a snapshot; others all agree with the snapshot.

Previously this code path was just broken (could fail horribly if
modules were unloaded after one of the opens is closed), so I just
blocked it off in an earlier commit, but that broke crash(8).  So
let's continue allowing multiple opens seeing the same snapshot, but
without the horrible bugs.


To generate a diff of this commit:
cvs rdiff -u -r1.96 -r1.97 src/sys/kern/kern_ksyms.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/evbppc/conf/DHT
diff -u src/sys/arch/evbppc/conf/DHT:1.1 src/sys/arch/evbppc/conf/DHT:1.2
--- src/sys/arch/evbppc/conf/DHT:1.1	Fri Apr  2 07:00:33 2021
+++ src/sys/arch/evbppc/conf/DHT	Thu Jun  3 09:09:22 2021
@@ -1,4 +1,4 @@
-#	$NetBSD: DHT,v 1.1 2021/04/02 07:00:33 rin Exp $
+#	$NetBSD: DHT,v 1.2 2021/06/03 09:09:22 rin Exp $
 #
 #	DHT --- DHT Walnut 405GP Evaluation Board
 #		(Digital Home Technologies PCB 01070201 Rev. 1.1)
@@ -8,7 +8,7 @@ include 	"arch/evbppc/conf/std.dht"
 
 options 	INCLUDE_CONFIG_FILE	# embed config file in kernel binary
 
-#ident 		"DHT-$Revision: 1.1 $"
+#ident 		"DHT-$Revision: 1.2 $"
 
 maxusers	32
 
@@ -49,7 +49,7 @@ options 	DIAGNOSTIC		# cheap kernel cons
 options 	DDB			# in-kernel debugger
 options 	DDB_HISTORY_SIZE=512	# enable history editing in DDB
 #options 	TRAP_PANICWAIT
-makeoptions	COPY_SYMTAB=1	# size for embedded symbol table
+makeoptions	COPY_SYMTAB=1		# size for embedded symbol table
 
 makeoptions	DEBUG="-g"		# compile full symbol table
 
@@ -177,6 +177,7 @@ siisata* at pci? dev ? function ?	# SiI 
 
 wm*	at pci? dev ? function ?	# Intel 82543/82544 gigabit
 igphy*	at mii? phy ?			# Intel IGP01E1000
+makphy* at mii? phy ?			# Marvell Semiconductor 88E1000 PHYs
 ukphy*	at mii? phy ?			# generic unknown PHYs
 
 xhci*	at pci?	dev ? function ?	# eXtensible Host Controller
@@ -204,7 +205,7 @@ pseudo-device	swcrypto		# software crypt
 #pseudo-device	cgd			# cryptographic disk devices
 #pseudo-device	raid			# RAIDframe disk driver
 #options 	RAID_AUTOCONFIG		# auto-configuration of RAID components
-#pseudo-device	fss			# file system snapshot device
+pseudo-device	fss			# file system snapshot device
 #pseudo-device	md			# memory disk device
 pseudo-device	vnd			# disk-like interface to files
 
@@ -231,6 +232,7 @@ pseudo-device	agr			# IEEE 802.3ad link 
 # miscellaneous pseudo-devices
 pseudo-device	pty			# pseudo-terminals
 pseudo-device	clockctl		# user control of clock subsystem
+pseudo-device	drvctl			# user control of drive subsystem
 pseudo-device	ksyms			# /dev/ksyms
 pseudo-device	putter			# for puffs and pud
 



CVS commit: src

2021-06-03 Thread Thomas Klausner
Module Name:src
Committed By:   wiz
Date:   Thu Jun  3 07:41:26 UTC 2021

Modified Files:
src/distrib/sets/lists/man: mi
src/share/man/man4/man4.i386: Makefile intro.4
src/share/man/man4/man4.x86: Makefile
Added Files:
src/share/man/man4/man4.x86: autoconf.4 console.4
Removed Files:
src/share/man/man4/man4.i386: autoconf.4 console.4

Log Message:
Remove i386/autoconf(4) and i386/console(4) to x86/autoconf(4) and 
x86/console(4)

Part of PR 36350.


To generate a diff of this commit:
cvs rdiff -u -r1.1720 -r1.1721 src/distrib/sets/lists/man/mi
cvs rdiff -u -r1.78 -r1.79 src/share/man/man4/man4.i386/Makefile
cvs rdiff -u -r1.11 -r0 src/share/man/man4/man4.i386/autoconf.4
cvs rdiff -u -r1.12 -r0 src/share/man/man4/man4.i386/console.4
cvs rdiff -u -r1.34 -r1.35 src/share/man/man4/man4.i386/intro.4
cvs rdiff -u -r1.21 -r1.22 src/share/man/man4/man4.x86/Makefile
cvs rdiff -u -r0 -r1.1 src/share/man/man4/man4.x86/autoconf.4 \
src/share/man/man4/man4.x86/console.4

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/distrib/sets/lists/man/mi
diff -u src/distrib/sets/lists/man/mi:1.1720 src/distrib/sets/lists/man/mi:1.1721
--- src/distrib/sets/lists/man/mi:1.1720	Mon May 17 04:07:42 2021
+++ src/distrib/sets/lists/man/mi	Thu Jun  3 07:41:26 2021
@@ -1,4 +1,4 @@
-# $NetBSD: mi,v 1.1720 2021/05/17 04:07:42 yamaguchi Exp $
+# $NetBSD: mi,v 1.1721 2021/06/03 07:41:26 wiz Exp $
 #
 # Note: don't delete entries from here - mark them as "obsolete" instead.
 #
@@ -1264,12 +1264,12 @@
 ./usr/share/man/cat4/hythygtemp.0		man-sys-catman		.cat
 ./usr/share/man/cat4/i386/PCIBIOS.0		man-sys-catman		.cat
 ./usr/share/man/cat4/i386/apm.0			man-sys-catman		.cat
-./usr/share/man/cat4/i386/autoconf.0		man-sys-catman		.cat
+./usr/share/man/cat4/i386/autoconf.0		man-obsolete		obsolete
 ./usr/share/man/cat4/i386/busmouse.0		man-obsolete		obsolete
 ./usr/share/man/cat4/i386/cmos.0		man-sys-catman		.cat
 ./usr/share/man/cat4/i386/com.0			man-obsolete		obsolete
-./usr/share/man/cat4/i386/cons.0		man-sys-catman		.cat
-./usr/share/man/cat4/i386/console.0		man-sys-catman		.cat
+./usr/share/man/cat4/i386/cons.0		man-obsolete		obsolete
+./usr/share/man/cat4/i386/console.0		man-obsolete		obsolete
 ./usr/share/man/cat4/i386/ed.0			man-sys-catman		.cat
 ./usr/share/man/cat4/i386/elanpar.0		man-sys-catman		.cat
 ./usr/share/man/cat4/i386/elanpex.0		man-sys-catman		.cat
@@ -2078,7 +2078,10 @@
 ./usr/share/man/cat4/x86/amdsmn.0		man-sys-catman		.cat
 ./usr/share/man/cat4/x86/amdzentemp.0		man-sys-catman		.cat
 ./usr/share/man/cat4/x86/apic.0			man-sys-catman		.cat
+./usr/share/man/cat4/x86/autoconf.0		man-sys-catman		.cat
 ./usr/share/man/cat4/x86/balloon.0		man-sys-catman		.cat
+./usr/share/man/cat4/x86/cons.0			man-sys-catman		.cat
+./usr/share/man/cat4/x86/console.0		man-sys-catman		.cat
 ./usr/share/man/cat4/x86/coretemp.0		man-sys-catman		.cat
 ./usr/share/man/cat4/x86/est.0			man-sys-catman		.cat
 ./usr/share/man/cat4/x86/fdc.0			man-sys-catman		.cat
@@ -4486,10 +4489,10 @@
 ./usr/share/man/html4/hythygtemp.html		man-sys-htmlman		html
 ./usr/share/man/html4/i386/PCIBIOS.html		man-sys-htmlman		html
 ./usr/share/man/html4/i386/apm.html		man-sys-htmlman		html
-./usr/share/man/html4/i386/autoconf.html	man-sys-htmlman		html
+./usr/share/man/html4/386/autoconf.html	man-obsolete		obsolete
 ./usr/share/man/html4/i386/cmos.html		man-sys-htmlman		html
-./usr/share/man/html4/i386/cons.html		man-sys-htmlman		html
-./usr/share/man/html4/i386/console.html		man-sys-htmlman		html
+./usr/share/man/html4/i386/cons.html		man-obsolete		obsolete
+./usr/share/man/html4/i386/console.html		man-obsolete		obsolete
 ./usr/share/man/html4/i386/ed.html		man-sys-htmlman		html
 ./usr/share/man/html4/i386/elanpar.html		man-sys-htmlman		html
 ./usr/share/man/html4/i386/elanpex.html		man-sys-htmlman		html
@@ -5231,7 +5234,10 @@
 ./usr/share/man/html4/x86/amdsmn.html		man-sys-htmlman		html
 ./usr/share/man/html4/x86/amdzentemp.html	man-sys-htmlman		html
 ./usr/share/man/html4/x86/apic.html		man-sys-htmlman		html
+./usr/share/man/html4/x86/autoconf.html		man-sys-htmlman		html
 ./usr/share/man/html4/x86/balloon.html		man-sys-htmlman		html
+./usr/share/man/html4/x86/cons.html		man-sys-htmlman		html
+./usr/share/man/html4/x86/console.html		man-sys-htmlman		html
 ./usr/share/man/html4/x86/coretemp.html		man-sys-htmlman		html
 ./usr/share/man/html4/x86/est.html		man-sys-htmlman		html
 ./usr/share/man/html4/x86/fdc.html		man-sys-htmlman		html
@@ -7501,12 +7507,12 @@
 ./usr/share/man/man4/hythygtemp.4		man-sys-man		.man
 ./usr/share/man/man4/i386/PCIBIOS.4		man-sys-man		.man
 ./usr/share/man/man4/i386/apm.4			man-sys-man		.man
-./usr/share/man/man4/i386/autoconf.4		man-sys-man		.man
+./usr/share/man/man4/i386/autoconf.4		man-obsolete		obsolete
 ./usr/share/man/man4/i386/busmouse.4		man-obsolete		obsolete
 ./usr/share/man/man4/i386/cmos.4		

CVS commit: src/share/mk

2021-06-03 Thread Rin Okuyama
Module Name:src
Committed By:   rin
Date:   Thu Jun  3 07:40:48 UTC 2021

Modified Files:
src/share/mk: bsd.own.mk bsd.x11.mk

Log Message:
Switch amiga to Xorg server 1.20; wsfb(4) is only graphic driver both for
1.10 and 1.20 (Xamiga was gone a long ago...), and there is no reason to
stay with 1.10.

At least, 1.20 works fine on wsdisplay(4) at amidisplaycc(4).


To generate a diff of this commit:
cvs rdiff -u -r1.1255 -r1.1256 src/share/mk/bsd.own.mk
cvs rdiff -u -r1.138 -r1.139 src/share/mk/bsd.x11.mk

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/share/mk/bsd.own.mk
diff -u src/share/mk/bsd.own.mk:1.1255 src/share/mk/bsd.own.mk:1.1256
--- src/share/mk/bsd.own.mk:1.1255	Sat May 29 12:25:08 2021
+++ src/share/mk/bsd.own.mk	Thu Jun  3 07:40:48 2021
@@ -1,4 +1,4 @@
-#	$NetBSD: bsd.own.mk,v 1.1255 2021/05/29 12:25:08 rin Exp $
+#	$NetBSD: bsd.own.mk,v 1.1256 2021/06/03 07:40:48 rin Exp $
 
 # This needs to be before bsd.init.mk
 .if defined(BSD_MK_COMPAT_FILE)
@@ -1580,7 +1580,6 @@ X11SRCDIR.${_proto}proto?=		${X11SRCDIRM
 # During transition from xorg-server 1.10 to 1.20
 .if \
 ${MACHINE} == "alpha"	|| \
-${MACHINE} == "amiga"	|| \
 ${MACHINE} == "netwinder"	|| \
 ${MACHINE} == "sgimips"	|| \
 ${MACHINE} == "vax"

Index: src/share/mk/bsd.x11.mk
diff -u src/share/mk/bsd.x11.mk:1.138 src/share/mk/bsd.x11.mk:1.139
--- src/share/mk/bsd.x11.mk:1.138	Tue Apr 27 04:02:09 2021
+++ src/share/mk/bsd.x11.mk	Thu Jun  3 07:40:48 2021
@@ -1,4 +1,4 @@
-#	$NetBSD: bsd.x11.mk,v 1.138 2021/04/27 04:02:09 mrg Exp $
+#	$NetBSD: bsd.x11.mk,v 1.139 2021/06/03 07:40:48 rin Exp $
 
 .include 
 
@@ -82,7 +82,6 @@ X11FLAGS.OS_DEFINES=	-DDDXOSINIT -DSERVE
 			-DDDXOSVERRORF -DDDXTIME -DUSB_HID
 
 .if !(${MACHINE} == "acorn32"	|| \
-${MACHINE} == "amiga"	|| \
 ${MACHINE} == "pmax"	|| \
 ${MACHINE} == "sun3"	|| \
 ${MACHINE} == "x68k"	|| \



CVS commit: src/external/mit/xorg/server/drivers/xf86-input-keyboard

2021-06-03 Thread Rin Okuyama
Module Name:src
Committed By:   rin
Date:   Thu Jun  3 07:37:01 UTC 2021

Modified Files:
src/external/mit/xorg/server/drivers/xf86-input-keyboard: Makefile

Log Message:
Sort ${MACHINE}'s. No functional changes.


To generate a diff of this commit:
cvs rdiff -u -r1.18 -r1.19 \
src/external/mit/xorg/server/drivers/xf86-input-keyboard/Makefile

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/mit/xorg/server/drivers/xf86-input-keyboard/Makefile
diff -u src/external/mit/xorg/server/drivers/xf86-input-keyboard/Makefile:1.18 src/external/mit/xorg/server/drivers/xf86-input-keyboard/Makefile:1.19
--- src/external/mit/xorg/server/drivers/xf86-input-keyboard/Makefile:1.18	Thu Jun  3 07:34:29 2021
+++ src/external/mit/xorg/server/drivers/xf86-input-keyboard/Makefile	Thu Jun  3 07:37:00 2021
@@ -1,4 +1,4 @@
-#	$NetBSD: Makefile,v 1.18 2021/06/03 07:34:29 rin Exp $
+#	$NetBSD: Makefile,v 1.19 2021/06/03 07:37:00 rin Exp $
 
 DRIVER=		xf86-input-keyboard
 DRIVER_NAME=	kbd_drv
@@ -13,11 +13,15 @@ CPPFLAGS+=	-DPCVT_SUPPORT
 # turns out we can't use wskbd everywhere without a couple more translation
 # tables in the X driver so make it the default only where we know it will work
 
-.if ${MACHINE_ARCH} == "powerpc" || ${MACHINE} == "sparc" || \
-${MACHINE} == "sparc64" || ${MACHINE} == "sgimips" || \
-${MACHINE} == "shark" || ${MACHINE} == "vax" || \
-${MACHINE} == "evbarm" || ${MACHINE} == "mac68k" || \
-${MACHINE} == "amiga"
+.if ${MACHINE_ARCH} == "powerpc" || \
+${MACHINE} == "amiga" || \
+${MACHINE} == "evbarm" || \
+${MACHINE} == "mac68k" || \
+${MACHINE} == "sgimips" || \
+${MACHINE} == "shark" || \
+${MACHINE} == "sparc" || \
+${MACHINE} == "sparc64" || \
+${MACHINE} == "vax"
 CPPFLAGS+=	-DDEFAULT_TO_WSKBD
 .endif
 



CVS commit: src/external/mit/xorg/server/drivers/xf86-input-keyboard

2021-06-03 Thread Rin Okuyama
Module Name:src
Committed By:   rin
Date:   Thu Jun  3 07:34:30 UTC 2021

Modified Files:
src/external/mit/xorg/server/drivers/xf86-input-keyboard: Makefile

Log Message:
For amiga, use wskbd as default, which is only supported protocol today.


To generate a diff of this commit:
cvs rdiff -u -r1.17 -r1.18 \
src/external/mit/xorg/server/drivers/xf86-input-keyboard/Makefile

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/mit/xorg/server/drivers/xf86-input-keyboard/Makefile
diff -u src/external/mit/xorg/server/drivers/xf86-input-keyboard/Makefile:1.17 src/external/mit/xorg/server/drivers/xf86-input-keyboard/Makefile:1.18
--- src/external/mit/xorg/server/drivers/xf86-input-keyboard/Makefile:1.17	Sat May 29 12:15:32 2021
+++ src/external/mit/xorg/server/drivers/xf86-input-keyboard/Makefile	Thu Jun  3 07:34:29 2021
@@ -1,4 +1,4 @@
-#	$NetBSD: Makefile,v 1.17 2021/05/29 12:15:32 rin Exp $
+#	$NetBSD: Makefile,v 1.18 2021/06/03 07:34:29 rin Exp $
 
 DRIVER=		xf86-input-keyboard
 DRIVER_NAME=	kbd_drv
@@ -16,7 +16,8 @@ CPPFLAGS+=	-DPCVT_SUPPORT
 .if ${MACHINE_ARCH} == "powerpc" || ${MACHINE} == "sparc" || \
 ${MACHINE} == "sparc64" || ${MACHINE} == "sgimips" || \
 ${MACHINE} == "shark" || ${MACHINE} == "vax" || \
-${MACHINE} == "evbarm" || ${MACHINE} == "mac68k"
+${MACHINE} == "evbarm" || ${MACHINE} == "mac68k" || \
+${MACHINE} == "amiga"
 CPPFLAGS+=	-DDEFAULT_TO_WSKBD
 .endif
 



CVS commit: src/sys/arch/amiga/dev

2021-06-03 Thread Rin Okuyama
Module Name:src
Committed By:   rin
Date:   Thu Jun  3 07:31:20 UTC 2021

Modified Files:
src/sys/arch/amiga/dev: kbd.c ms.c

Log Message:
kbd(4) and ms(4) carry multiple interface attributes. They are configurable
both as standalone drivers for legacy framebuffer console, or parents of
wskbd(4) and wsmouse(4), respectively. For the latter, be explicit about
using "wskbddev" and "wsmousedev" interface attributes for children.


To generate a diff of this commit:
cvs rdiff -u -r1.59 -r1.60 src/sys/arch/amiga/dev/kbd.c
cvs rdiff -u -r1.40 -r1.41 src/sys/arch/amiga/dev/ms.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/amiga/dev/kbd.c
diff -u src/sys/arch/amiga/dev/kbd.c:1.59 src/sys/arch/amiga/dev/kbd.c:1.60
--- src/sys/arch/amiga/dev/kbd.c:1.59	Sat Apr 24 23:36:24 2021
+++ src/sys/arch/amiga/dev/kbd.c	Thu Jun  3 07:31:20 2021
@@ -1,4 +1,4 @@
-/*	$NetBSD: kbd.c,v 1.59 2021/04/24 23:36:24 thorpej Exp $ */
+/*	$NetBSD: kbd.c,v 1.60 2021/06/03 07:31:20 rin Exp $ */
 
 /*
  * Copyright (c) 1982, 1986, 1990 The Regents of the University of California.
@@ -32,7 +32,7 @@
  */
 
 #include 
-__KERNEL_RCSID(0, "$NetBSD: kbd.c,v 1.59 2021/04/24 23:36:24 thorpej Exp $");
+__KERNEL_RCSID(0, "$NetBSD: kbd.c,v 1.60 2021/06/03 07:31:20 rin Exp $");
 
 #include 
 #include 
@@ -220,6 +220,7 @@ kbdattach(device_t parent, device_t self
 		waa.accessops = _accessops;
 		waa.accesscookie = NULL;
 		kbd_softc.k_wskbddev = config_found(self, , wskbddevprint,
+		CFARG_IATTR, "wskbddev",
 		CFARG_EOL);
 
 		kbd_softc.k_pollingmode = 0;

Index: src/sys/arch/amiga/dev/ms.c
diff -u src/sys/arch/amiga/dev/ms.c:1.40 src/sys/arch/amiga/dev/ms.c:1.41
--- src/sys/arch/amiga/dev/ms.c:1.40	Sat Apr 24 23:36:24 2021
+++ src/sys/arch/amiga/dev/ms.c	Thu Jun  3 07:31:20 2021
@@ -1,4 +1,4 @@
-/*	$NetBSD: ms.c,v 1.40 2021/04/24 23:36:24 thorpej Exp $ */
+/*	$NetBSD: ms.c,v 1.41 2021/06/03 07:31:20 rin Exp $ */
 
 /*
  * based on:
@@ -45,7 +45,7 @@
  */
 
 #include 
-__KERNEL_RCSID(0, "$NetBSD: ms.c,v 1.40 2021/04/24 23:36:24 thorpej Exp $");
+__KERNEL_RCSID(0, "$NetBSD: ms.c,v 1.41 2021/06/03 07:31:20 rin Exp $");
 
 /*
  * Mouse driver.
@@ -202,7 +202,9 @@ msattach(device_t parent, device_t self,
 		
 		sc->sc_ports[i].ms_wsenabled = 0;
 		sc->sc_ports[i].ms_wsmousedev = 
-		config_found(self, , wsmousedevprint, CFARG_EOL);
+		config_found(self, , wsmousedevprint,
+			CFARG_IATTR, "wsmousedev",
+			CFARG_EOL);
 #endif
 	}
 }



CVS commit: src/sys/arch/arm/arm32

2021-06-03 Thread Nick Hudson
Module Name:src
Committed By:   skrll
Date:   Thu Jun  3 07:06:22 UTC 2021

Modified Files:
src/sys/arch/arm/arm32: arm32_boot.c

Log Message:
Mirror changes to passing pages to UVM into aarch64_machdep.c

Two fixes for loading free pages into UVM

- Only consider a boot_physmem (inner loop) range that has its end
  (bp_end) after the bootconfig.dram (outer loop) range start (start).
  This was harmless as a later condition correctly checks there is only
  something to do if start < bp_end.

- Stop processing boot_physmem ranges if all the bootconfig.dram range has
  been passed to UVM.  This fixes a boot problem for simon@

Copy a comment over and do the VPRINTF before the uvm_page_physload in
the same way as aarch64_machdep.c as well.


To generate a diff of this commit:
cvs rdiff -u -r1.42 -r1.43 src/sys/arch/arm/arm32/arm32_boot.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/arm/arm32/arm32_boot.c
diff -u src/sys/arch/arm/arm32/arm32_boot.c:1.42 src/sys/arch/arm/arm32/arm32_boot.c:1.43
--- src/sys/arch/arm/arm32/arm32_boot.c:1.42	Tue Jun  1 16:55:07 2021
+++ src/sys/arch/arm/arm32/arm32_boot.c	Thu Jun  3 07:06:22 2021
@@ -1,4 +1,4 @@
-/*	$NetBSD: arm32_boot.c,v 1.42 2021/06/01 16:55:07 skrll Exp $	*/
+/*	$NetBSD: arm32_boot.c,v 1.43 2021/06/03 07:06:22 skrll Exp $	*/
 
 /*
  * Copyright (c) 2002, 2003, 2005  Genetec Corporation.  All rights reserved.
@@ -122,7 +122,7 @@
  */
 
 #include 
-__KERNEL_RCSID(1, "$NetBSD: arm32_boot.c,v 1.42 2021/06/01 16:55:07 skrll Exp $");
+__KERNEL_RCSID(1, "$NetBSD: arm32_boot.c,v 1.43 2021/06/03 07:06:22 skrll Exp $");
 
 #include "opt_arm_debug.h"
 #include "opt_cputypes.h"
@@ -261,15 +261,21 @@ initarm_common(vaddr_t kvm_base, vsize_t
 			continue;
 		}
 		VPRINTF("\n");
+
+		/*
+		 * This assumes the bp list is sorted in ascending
+		 * order.
+		 */
 		paddr_t segend = end;
-		for (size_t j = 0; j < nbp; j++) {
+		for (size_t j = 0; j < nbp && start < end; j++) {
 			paddr_t bp_start = bp[j].bp_start;
 			paddr_t bp_end = bp_start + bp[j].bp_pages;
 
 			VPRINTF("   bp %2zu start %08lx  end %08lx\n",
 			j, ptoa(bp_start), ptoa(bp_end));
+
 			KASSERT(bp_start < bp_end);
-			if (start > bp_end || segend < bp_start)
+			if (start >= bp_end || segend < bp_start)
 continue;
 
 			if (start < bp_start)
@@ -281,11 +287,13 @@ initarm_common(vaddr_t kvm_base, vsize_t
 }
 vm_freelist = bp[j].bp_freelist;
 
-uvm_page_physload(start, segend, start, segend,
-vm_freelist);
 VPRINTF(" start %08lx  end %08lx"
 "... loading in freelist %d\n", ptoa(start),
 ptoa(segend), vm_freelist);
+
+uvm_page_physload(start, segend, start, segend,
+vm_freelist);
+
 start = segend;
 segend = end;
 			}



CVS commit: src/sys/arch/aarch64/aarch64

2021-06-03 Thread Nick Hudson
Module Name:src
Committed By:   skrll
Date:   Thu Jun  3 07:02:59 UTC 2021

Modified Files:
src/sys/arch/aarch64/aarch64: aarch64_machdep.c

Log Message:
Two fixes for loading free pages into UVM

- Only consider a boot_physmem (inner loop) range that has its end
  (bp_end) after the bootconfig.dram (outer loop) range start (start).
  This was harmless as a later condition correctly checks there is only
  something to do if start < bp_end.

- Stop processing boot_physmem ranges if all the bootconfig.dram range has
  been passed to UVM.  This fixes a boot problem for simon@


To generate a diff of this commit:
cvs rdiff -u -r1.60 -r1.61 src/sys/arch/aarch64/aarch64/aarch64_machdep.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/aarch64/aarch64/aarch64_machdep.c
diff -u src/sys/arch/aarch64/aarch64/aarch64_machdep.c:1.60 src/sys/arch/aarch64/aarch64/aarch64_machdep.c:1.61
--- src/sys/arch/aarch64/aarch64/aarch64_machdep.c:1.60	Thu Mar 25 07:31:56 2021
+++ src/sys/arch/aarch64/aarch64/aarch64_machdep.c	Thu Jun  3 07:02:59 2021
@@ -1,4 +1,4 @@
-/* $NetBSD: aarch64_machdep.c,v 1.60 2021/03/25 07:31:56 skrll Exp $ */
+/* $NetBSD: aarch64_machdep.c,v 1.61 2021/06/03 07:02:59 skrll Exp $ */
 
 /*-
  * Copyright (c) 2014 The NetBSD Foundation, Inc.
@@ -30,7 +30,7 @@
  */
 
 #include 
-__KERNEL_RCSID(1, "$NetBSD: aarch64_machdep.c,v 1.60 2021/03/25 07:31:56 skrll Exp $");
+__KERNEL_RCSID(1, "$NetBSD: aarch64_machdep.c,v 1.61 2021/06/03 07:02:59 skrll Exp $");
 
 #include "opt_arm_debug.h"
 #include "opt_cpuoptions.h"
@@ -391,12 +391,15 @@ initarm_common(vaddr_t kvm_base, vsize_t
 		 * order.
 		 */
 		paddr_t segend = end;
-		for (size_t j = 0; j < nbp; j++) {
+		for (size_t j = 0; j < nbp && start < end; j++) {
 			paddr_t bp_start = bp[j].bp_start;
 			paddr_t bp_end = bp_start + bp[j].bp_pages;
 
+			VPRINTF("   bp %2zu start %08lx  end %08lx\n",
+			j, ptoa(bp_start), ptoa(bp_end));
+
 			KASSERT(bp_start < bp_end);
-			if (start > bp_end || segend < bp_start)
+			if (start >= bp_end || segend < bp_start)
 continue;
 
 			if (start < bp_start)
@@ -414,6 +417,7 @@ initarm_common(vaddr_t kvm_base, vsize_t
 
 uvm_page_physload(start, segend, start, segend,
 vm_freelist);
+
 memsize_total += ptoa(segend - start);
 start = segend;
 segend = end;
Index: src/sys/kern/kern_ksyms.c
diff -u src/sys/kern/kern_ksyms.c:1.96 src/sys/kern/kern_ksyms.c:1.97
--- src/sys/kern/kern_ksyms.c:1.96	Thu Jun  3 01:00:24 2021
+++ src/sys/kern/kern_ksyms.c	Thu Jun  3 09:22:47 2021
@@ -1,4 +1,4 @@
-/*	$NetBSD: kern_ksyms.c,v 1.96 2021/06/03 01:00:24 riastradh Exp $	*/
+/*	$NetBSD: kern_ksyms.c,v 1.97 2021/06/03 09:22:47 riastradh Exp $	*/
 
 /*-
  * Copyright (c) 2008 The NetBSD Foundation, Inc.
@@ -73,7 +73,7 @@
  */
 
 #include 
-__KERNEL_RCSID(0, "$NetBSD: kern_ksyms.c,v 1.96 2021/06/03 01:00:24 riastradh Exp $");
+__KERNEL_RCSID(0, "$NetBSD: kern_ksyms.c,v 1.97 2021/06/03 09:22:47 riastradh Exp $");
 
 #if defined(_KERNEL) && defined(_KERNEL_OPT)
 #include "opt_copy_symtab.h"
@@ -112,7 +112,7 @@ static uint32_t *ksyms_nmap = NULL;
 #endif
 
 static int ksyms_maxlen;
-static bool ksyms_isopen;
+static uint64_t ksyms_opencnt;
 static struct ksyms_symtab *ksyms_last_snapshot;
 static bool ksyms_initted;
 static bool ksyms_loaded;
@@ -791,7 +791,7 @@ ksyms_modunload(const char *name)
 			continue;
 		st->sd_gone = true;
 		ksyms_sizes_calc();
-		if (!ksyms_isopen) {
+		if (ksyms_opencnt == 0) {
 			/*
 			 * Ensure ddb never witnesses an inconsistent
 			 * state of the queue, unless memory is so
@@ -1004,14 +1004,12 @@ ksymsopen(dev_t dev, int oflags, int dev
 		return ENXIO;
 
 	/*
 	 * Create a "snapshot" of the kernel symbol table.  Setting
 	 * ksyms_isopen will prevent symbol tables from being freed.
 	 */
 	mutex_enter(_lock);
-	if (ksyms_isopen) {
-		mutex_exit(_lock);
-		return EBUSY;
-	}
+	if (ksyms_opencnt++)
+		goto out;
 	ksyms_hdr.kh_shdr[SYMTAB].sh_size = ksyms_symsz;
 	ksyms_hdr.kh_shdr[SYMTAB].sh_info = ksyms_symsz / sizeof(Elf_Sym);
 	ksyms_hdr.kh_shdr[STRTAB].sh_offset = ksyms_symsz +
@@ -1020,9 +1018,8 @@ ksymsopen(dev_t dev, int oflags, int dev
 	ksyms_hdr.kh_shdr[SHCTF].sh_offset = ksyms_strsz +
 	ksyms_hdr.kh_shdr[STRTAB].sh_offset;
 	ksyms_hdr.kh_shdr[SHCTF].sh_size = ksyms_ctfsz;
-	ksyms_isopen = true;
 	ksyms_last_snapshot = TAILQ_LAST(_symtabs, ksyms_symtab_queue);
-	mutex_exit(_lock);
+out:	mutex_exit(_lock);
 
 	return 0;
 }
@@ -1036,7 +1033,8 @@ ksymsclose(dev_t dev, int oflags, int de
 
 	/* Discard references to symbol tables. */
 	mutex_enter(_lock);
-	ksyms_isopen = false;
+	if (--ksyms_opencnt)
+		goto out;
 	ksyms_last_snapshot = NULL;
 	TAILQ_FOREACH_SAFE(st, _symtabs, sd_queue, next) {
 		if (st->sd_gone) {
@@ -1053,7 +1051,7 @@ ksymsclose(dev_t dev, int oflags, int de
 	}
 	if (!TAILQ_EMPTY(_free))
 		ksyms_sizes_calc();
-	mutex_exit(_lock);
+out:	mutex_exit(_lock);
 
 	TAILQ_FOREACH_SAFE(st, _free, sd_queue, next) {
 		kmem_free(st->sd_nmap, st->sd_nmapsize * sizeof(uint32_t));



CVS commit: src/sys/arch/evbppc/conf

2021-06-03 Thread Rin Okuyama
Module Name:src
Committed By:   rin
Date:   Thu Jun  3 09:09:22 UTC 2021

Modified Files:
src/sys/arch/evbppc/conf: DHT

Log Message:
- Add some more things necessary for ATF.
- Add makphy(4) found in recent wm(4) models.
- Style.
@@ -1004,14 +1004,12 @@ ksymsopen(dev_t dev, int oflags, int dev
 
 	/*
-	 * Create a "snapshot" of the kernel symbol table.  Setting
-	 * ksyms_isopen will prevent symbol tables from being freed.
+	 * Create a "snapshot" of the kernel symbol table.  Bumping
+	 * ksyms_opencnt will prevent symbol tables from being freed.
 	 */
 	mutex_enter(_lock);


To generate a diff of this commit:
cvs rdiff -u -r1.1 -r1.2 src/sys/arch/evbppc/conf/DHT

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:
